package com.ruoyi.project.project.cases.mapper;

import com.ruoyi.project.project.cases.domain.Case;

import java.util.List;

/**
 * 案件 数据层
 * 
 * @author luoluo
 */
public interface CaseMapper
{
    /**
     * 查询案件信息
     * 
     * @param id
     * @return 案件信息
     */
    public Case selectCaseById(Integer id);

    /**
     * 查询案件列表
     * 
     * @param cases 案件信息
     * @return 案件集合
     */
     
    public List<Case> selectCaseList(Case cases);

    /**
     * 新增案件
     * 
     * @param cases 案件信息
     * @return 结果
     */
    public int insertCase(Case cases);

    /**
     * 修改案件
     * 
     * @param cases 案件信息
     * @return 结果
     */
    public int updateCase(Case cases);

    /**
     * 批量删除案件
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteCaseByIds(Integer[] ids);

    int selectCaseByCaseNo(String caseNo);
}